Skip to contents

Loads a generalized fit object from an .RData or .json file, or accepts an already-loaded list and ensures all table components (SDTAB, EVTAB, COTAB, CATAB, SUMTAB) are proper data frames.

Usage

read_smrg_obj(fpath_i)

Arguments

fpath_i

String, GFO, or a named list with a GFO component (and optionally GCO). If a string is given, the path to a .RData or .json file with a fit object is expected.

Value

GFO, or a named list with GFO (and optionally GCO) components, with all table components coerced to data frames.

Examples

# Pass an already-loaded sg-fit object
obj <- read_smrg_obj(gfo4cov)
class(obj$SDTAB)
#> [1] "data.frame"