Final parameter estimates from a warfarin population pharmacokinetic model, including typical values, covariate effects, random effects, and residual error parameters with associated uncertainty measures.
Format
parest
A data frame with 15 rows and 12 columns:
- parameter
parameter name as used in the model
- value
final parameter estimate
- TYPE
parameter category:
"Typical values","Covariate effects","Random effects", or"Residual error model"- EST
estimation status (
"ESTIMATED")- SE
standard error of the estimate
- RSE
relative standard error (%)
- LCI
lower bound of the 95 % confidence interval
- UCI
upper bound of the 95 % confidence interval
- ETAshrinkage_var
ETA shrinkage on the variance scale (%);
NAfor non-random-effect parameters- ETAshrinkage_sd
ETA shrinkage on the SD scale (%);
NAfor non-random-effect parameters- EPSshrinkage_sd
EPS shrinkage on the SD scale (%);
NAfor non-residual-error parameters