Returns dataframe with summary statistics for model comparison
Arguments
- fpath_i
String, GFO, or a named list with a
GFOcomponent (and optionallyGCO). If a string is given, the path to a.RDataor.jsonfile with a fit object is expected.- run_id
Integer. Tested model ID. Default is 1.
Value
Data frame with model comparison metrics derived from GFO $OFV and
related fit outputs.
Examples
fpath_i <- system.file("extdata", "simurg_object", "Warfarin_PK.RData", package = "SimuRg")
#> Warning: cannot open compressed file '/tmp/RtmpLedq7K/temp_libpath8b6abff614d/SimuRg/DESCRIPTION', probable reason 'No such file or directory'
sum_tab <- sg_modcomp(fpath_i, 3)
#> Error: cannot open file '/tmp/RtmpLedq7K/temp_libpath8b6abff614d/SimuRg/R/SimuRg.rdb': No such file or directory
print(sum_tab)
#> Error: object 'sum_tab' not found